/*******************************************************************************
* File Name: Clk48.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "Clk48.h"


/*******************************************************************************
* Function Name: Clk48_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void Clk48_Write(uint8 value) 
{
    uint8 staticBits = (Clk48_DR & (uint8)(~Clk48_MASK));
    Clk48_DR = staticBits | ((uint8)(value << Clk48_SHIFT) & Clk48_MASK);
}


/*******************************************************************************
* Function Name: Clk48_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  Clk48_DM_STRONG     Strong Drive 
*  Clk48_DM_OD_HI      Open Drain, Drives High 
*  Clk48_DM_OD_LO      Open Drain, Drives Low 
*  Clk48_DM_RES_UP     Resistive Pull Up 
*  Clk48_DM_RES_DWN    Resistive Pull Down 
*  Clk48_DM_RES_UPDWN  Resistive Pull Up/Down 
*  Clk48_DM_DIG_HIZ    High Impedance Digital 
*  Clk48_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void Clk48_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(Clk48_0, mode);
}


/*******************************************************************************
* Function Name: Clk48_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro Clk48_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 Clk48_Read(void) 
{
    return (Clk48_PS & Clk48_MASK) >> Clk48_SHIFT;
}


/*******************************************************************************
* Function Name: Clk48_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 Clk48_ReadDataReg(void) 
{
    return (Clk48_DR & Clk48_MASK) >> Clk48_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(Clk48_INTSTAT) 

    /*******************************************************************************
    * Function Name: Clk48_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 Clk48_ClearInterrupt(void) 
    {
        return (Clk48_INTSTAT & Clk48_MASK) >> Clk48_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
