/*******************************************************************************
* File Name: NF_Output.c  
* Version 2.5
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "NF_Output.h"


/*******************************************************************************
* Function Name: NF_Output_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None 
*  
*******************************************************************************/
void NF_Output_Write(uint8 value) 
{
    uint8 staticBits = (NF_Output_DR & (uint8)(~NF_Output_MASK));
    NF_Output_DR = staticBits | ((uint8)(value << NF_Output_SHIFT) & NF_Output_MASK);
}


/*******************************************************************************
* Function Name: NF_Output_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  NF_Output_DM_STRONG     Strong Drive 
*  NF_Output_DM_OD_HI      Open Drain, Drives High 
*  NF_Output_DM_OD_LO      Open Drain, Drives Low 
*  NF_Output_DM_RES_UP     Resistive Pull Up 
*  NF_Output_DM_RES_DWN    Resistive Pull Down 
*  NF_Output_DM_RES_UPDWN  Resistive Pull Up/Down 
*  NF_Output_DM_DIG_HIZ    High Impedance Digital 
*  NF_Output_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void NF_Output_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(NF_Output_0, mode);
}


/*******************************************************************************
* Function Name: NF_Output_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro NF_Output_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 NF_Output_Read(void) 
{
    return (NF_Output_PS & NF_Output_MASK) >> NF_Output_SHIFT;
}


/*******************************************************************************
* Function Name: NF_Output_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 NF_Output_ReadDataReg(void) 
{
    return (NF_Output_DR & NF_Output_MASK) >> NF_Output_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(NF_Output_INTSTAT) 

    /*******************************************************************************
    * Function Name: NF_Output_ClearInterrupt
    ********************************************************************************
    *
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 NF_Output_ClearInterrupt(void) 
    {
        return (NF_Output_INTSTAT & NF_Output_MASK) >> NF_Output_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 


/* [] END OF FILE */
