/*******************************************************************************
* File Name: Counter_MilliSek_PM.c  
* Version 2.40
*
*  Description:
*    This file provides the power management source code to API for the
*    Counter.  
*
*   Note:
*     None
*
*******************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#include "Counter_MilliSek.h"

static Counter_MilliSek_backupStruct Counter_MilliSek_backup;


/*******************************************************************************
* Function Name: Counter_MilliSek_SaveConfig
********************************************************************************
* Summary:
*     Save the current user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_MilliSek_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void Counter_MilliSek_SaveConfig(void) 
{
    #if (!Counter_MilliSek_UsingFixedFunction)

        Counter_MilliSek_backup.CounterUdb = Counter_MilliSek_ReadCounter();

        #if (CY_UDB_V0)
            Counter_MilliSek_backup.CounterPeriod = Counter_MilliSek_ReadPeriod();
            Counter_MilliSek_backup.CompareValue = Counter_MilliSek_ReadCompare();
            Counter_MilliSek_backup.InterruptMaskValue = Counter_MilliSek_STATUS_MASK;
        #endif /* CY_UDB_V0 */

        #if(!Counter_MilliSek_ControlRegRemoved)
            Counter_MilliSek_backup.CounterControlRegister = Counter_MilliSek_ReadControlRegister();
        #endif /* (!Counter_MilliSek_ControlRegRemoved) */

    #endif /* (!Counter_MilliSek_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Counter_MilliSek_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_MilliSek_backup:  Variables of this global structure are used to 
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void Counter_MilliSek_RestoreConfig(void) 
{      
    #if (!Counter_MilliSek_UsingFixedFunction)

        #if (CY_UDB_V0)
            uint8 Counter_MilliSek_interruptState;
        #endif  /* (CY_UDB_V0) */

       Counter_MilliSek_WriteCounter(Counter_MilliSek_backup.CounterUdb);

        #if (CY_UDB_V0)
            Counter_MilliSek_WritePeriod(Counter_MilliSek_backup.CounterPeriod);
            Counter_MilliSek_WriteCompare(Counter_MilliSek_backup.CompareValue);

            Counter_MilliSek_interruptState = CyEnterCriticalSection();
            Counter_MilliSek_STATUS_AUX_CTRL |= Counter_MilliSek_STATUS_ACTL_INT_EN_MASK;
            CyExitCriticalSection(Counter_MilliSek_interruptState);

            Counter_MilliSek_STATUS_MASK = Counter_MilliSek_backup.InterruptMaskValue;
        #endif  /* (CY_UDB_V0) */

        #if(!Counter_MilliSek_ControlRegRemoved)
            Counter_MilliSek_WriteControlRegister(Counter_MilliSek_backup.CounterControlRegister);
        #endif /* (!Counter_MilliSek_ControlRegRemoved) */

    #endif /* (!Counter_MilliSek_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: Counter_MilliSek_Sleep
********************************************************************************
* Summary:
*     Stop and Save the user configuration
*
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_MilliSek_backup.enableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void Counter_MilliSek_Sleep(void) 
{
    #if(!Counter_MilliSek_ControlRegRemoved)
        /* Save Counter's enable state */
        if(Counter_MilliSek_CTRL_ENABLE == (Counter_MilliSek_CONTROL & Counter_MilliSek_CTRL_ENABLE))
        {
            /* Counter is enabled */
            Counter_MilliSek_backup.CounterEnableState = 1u;
        }
        else
        {
            /* Counter is disabled */
            Counter_MilliSek_backup.CounterEnableState = 0u;
        }
    #else
        Counter_MilliSek_backup.CounterEnableState = 1u;
        if(Counter_MilliSek_backup.CounterEnableState != 0u)
        {
            Counter_MilliSek_backup.CounterEnableState = 0u;
        }
    #endif /* (!Counter_MilliSek_ControlRegRemoved) */
    
    Counter_MilliSek_Stop();
    Counter_MilliSek_SaveConfig();
}


/*******************************************************************************
* Function Name: Counter_MilliSek_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  Counter_MilliSek_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void Counter_MilliSek_Wakeup(void) 
{
    Counter_MilliSek_RestoreConfig();
    #if(!Counter_MilliSek_ControlRegRemoved)
        if(Counter_MilliSek_backup.CounterEnableState == 1u)
        {
            /* Enable Counter's operation */
            Counter_MilliSek_Enable();
        } /* Do nothing if Counter was disabled before */    
    #endif /* (!Counter_MilliSek_ControlRegRemoved) */
    
}


/* [] END OF FILE */
